Option Explicit On
Option Strict On

Imports System
Imports DevExpress.XtraEditors
Imports DevExpress.Utils
Imports DevExpress.XtraEditors.Repository
Imports DevExpress.XtraEditors.Registrator

Imports System.Windows.Forms
Imports System.Drawing
Imports System.ComponentModel
Imports System.Reflection
Imports System.Drawing.Imaging

Imports Keyoti.RapidSpell


'* Copyright 2006-2007 Keyoti Inc.
'* This file may be modified and redistributed at your own risk.
'* 
'* Version 1.1 - For use with Keyoti RapidSpell Desktop .NET v3.7 up.
'* 
'* Changes:
'*	1.1 Added RepositoryItemAYTMemoExEdit class for grid column use.
'*		Modified namespace to KeyotiX... to correct VB.NET type resolution issue
'* 
'* Any modifications, or improvements to this are welcomed!  Please email to support@keyoti.com
'* 
'* ***************************************************************************************************************************
'* Visual Studio 2005 Users - Please find "VS2005 Uncomment" lines below and uncomment them for .NET 2 specific functionality.
'* ***************************************************************************************************************************
'* 
'* 
'* Look for "Option -" below for more options


Namespace KeyotiX.RapidSpell.ThirdParty.DevExpress6.Glue

    Public Class GlueVars
        Public Shared UnderlineYOffset As Integer = 0
        Public Shared UnderlineStyle As Keyoti.RapidSpell.UnderlineStyle = Keyoti.RapidSpell.UnderlineStyle.Single

        ' Option - wavy underlines (these may work better with bigger fonts and UnderlineYOffset=0)
        'Public Shared UnderlineYOffset As Integer = 2
        'Public Shared UnderlineStyle As Keyoti.RapidSpell.UnderlineStyle = Keyoti.RapidSpell.UnderlineStyle.Wavy

    End Class

#Region "Grid"

    ''' <summary>
    ''' As You Type TextEdit repository item
    ''' </summary>
    <UserRepositoryItem("Register")> _
    Public Class RepositoryItemAYTTextEdit
        Inherits DevExpress.XtraEditors.Repository.RepositoryItemTextEdit

        ''' <summary>
        ''' Shared instance of the spell checker
        ''' </summary>
        Public Shared RapidSpell As Keyoti.RapidSpell.RapidSpellAsYouType

        Friend Const EditorName As String = "AYTTextEdit"

        Shared Sub New()
            Register()
        End Sub

        Public Overrides ReadOnly Property EditorTypeName() As String
            Get
                Return EditorName
            End Get
        End Property

        ''' <summary>
        ''' Needs to be called in Form .ctor
        ''' </summary>
        Public Shared Sub InitRapidSpellAsYouType()
            If RepositoryItemAYTTextEdit.RapidSpell Is Nothing Then

                RepositoryItemAYTTextEdit.RapidSpell = New Keyoti.RapidSpell.RapidSpellAsYouType
                'RepositoryItemAYTTextEdit.RapidSpell.UserDictionaryFile = "user-dic.txt"
                RepositoryItemAYTTextEdit.RapidSpell.IncludeUserDictionaryInSuggestions = True
                RepositoryItemAYTTextEdit.RapidSpell.ShowSuggestionsWhenTextIsSelected = True
                'You may prefer to use single underlines because not much room for wavy
                RepositoryItemAYTTextEdit.RapidSpell.UnderlineStyle = GlueVars.UnderlineStyle
                'VS2005 Uncomment
                RepositoryItemAYTTextEdit.RapidSpell.ContextMenuStripEnabled = False
            End If
        End Sub

        Public Shared Sub Register()
            EditorRegistrationInfo.Default.Editors.Add(New EditorClassInfo(EditorName, GetType(AYTTextEdit), _
                GetType(RepositoryItemAYTTextEdit), _
                GetType(DevExpress.XtraEditors.ViewInfo.TextEditViewInfo), _
                New AYTTextEditPainter, True))
        End Sub
    End Class

    ''' <summary>
    ''' Paints the AYT Text Box when not in edit mode - this code draws the red "e" in the corner of the cell.
    ''' </summary>
    Public Class AYTTextEditPainter
        Inherits DevExpress.XtraEditors.Drawing.TextEditPainter

        Protected Overrides Sub DrawString(ByVal info As DevExpress.XtraEditors.Drawing.ControlGraphicsInfoArgs, ByVal bounds As Rectangle, ByVal text As String, ByVal appearance As DevExpress.Utils.AppearanceObject)
            ' Option - uncomment block for desired 'off-edit-mode' painting. 
            ' Paints an "e" in the corner -->
            'If (Not (RepositoryItemAYTTextEdit.RapidSpell) Is Nothing) Then
            '    'use the core spell checker from the as you type object
            '    Dim rsc As Keyoti.RapidSpell.RapidSpellChecker = RepositoryItemAYTTextEdit.RapidSpell.RapidSpellChecker
            '    rsc.ShareDictionary = True
            '    rsc.WarnDuplicates = False
            '    'check the text for errors
            '    rsc.Check(text)
            '    If (Not (rsc.NextBadWord) Is Nothing) Then
            '        info.Graphics.DrawString("e", New Font("Arial", 7), System.Drawing.Brushes.Red, New PointF((info.Bounds.Right - 7), info.Bounds.Top))
            '    End If
            'End If


            ' Paints an underline -->
            If (Not (RepositoryItemAYTTextEdit.RapidSpell) Is Nothing) Then
                Dim rsc As Keyoti.RapidSpell.RapidSpellChecker = RepositoryItemAYTTextEdit.RapidSpell.RapidSpellChecker
                rsc.Check(text)
                Dim bw As Keyoti.RapidSpell.BadWord

                Do
                    bw = rsc.NextBadWord()
                    If Not bw Is Nothing Then
                        Dim beforeWordWidth As Integer = Keyoti.RapidSpell.Grid.GridUtilities.MeasureDisplayStringWidth(info.Graphics, text.Substring(0, bw.StartPosition), appearance.Font, info.Bounds.Width, "")
                        Dim wordWidth As Integer = Keyoti.RapidSpell.Grid.GridUtilities.MeasureDisplayStringWidth(info.Graphics, bw.Word, info.ViewInfo.Appearance.Font, info.Bounds.Width, "")
                        Dim wordSize As SizeF = info.Graphics.MeasureString(bw.Word, info.ViewInfo.Appearance.Font)
                        Dim start As Point = New Point(CType((info.Bounds.Left + beforeWordWidth), Integer), CType((info.Bounds.Top _
                                        + (wordSize.Height + 1 - GlueVars.UnderlineYOffset)), Integer))
                        Dim endP As Point = New Point(CType((info.Bounds.Left _
                                        + (beforeWordWidth + wordWidth)), Integer), CType((info.Bounds.Top _
                                        + (wordSize.Height + 1 - GlueVars.UnderlineYOffset)), Integer))
                        Keyoti.RapidSpell.TextBoxUtilityAdapter.paintUnderline(info.Graphics, start, endP, RepositoryItemAYTTextEdit.RapidSpell.UnderlineStyle, New Pen(RepositoryItemAYTTextEdit.RapidSpell.UnderlineColor))
                    End If
                Loop While Not bw Is Nothing

            End If
            '<--

            MyBase.DrawString(info, bounds, text, appearance)
        End Sub
    End Class


    ''' <summary>
    ''' As You Type MemoExEdit repository item
    ''' </summary>
    <UserRepositoryItem("Register")> _
    Public Class RepositoryItemAYTMemoExEdit
        Inherits DevExpress.XtraEditors.Repository.RepositoryItemMemoExEdit

        ''' <summary>
        ''' Shared instance of the spell checker
        ''' </summary>
        Public Shared RapidSpell As Keyoti.RapidSpell.RapidSpellAsYouType

        Friend Const EditorName As String = "AYTMemoExEdit"

        Shared Sub New()
            Register()

        End Sub

        Public Overrides ReadOnly Property EditorTypeName() As String
            Get
                Return EditorName
            End Get
        End Property

        ''' <summary>
        ''' Needs to be called in Form .ctor
        ''' </summary>
        Public Shared Sub InitRapidSpellAsYouType()
            If RepositoryItemAYTMemoExEdit.RapidSpell Is Nothing Then

                RepositoryItemAYTMemoExEdit.RapidSpell = New Keyoti.RapidSpell.RapidSpellAsYouType
                'RepositoryItemAYTMemoExEdit.RapidSpell.UserDictionaryFile = "user-dic.txt"
                RepositoryItemAYTMemoExEdit.RapidSpell.IncludeUserDictionaryInSuggestions = True
                RepositoryItemAYTMemoExEdit.RapidSpell.ShowSuggestionsWhenTextIsSelected = True
                'You may prefer to use single underlines because not much room for wavy
                RepositoryItemAYTMemoExEdit.RapidSpell.UnderlineStyle = GlueVars.UnderlineStyle
                'VS2005 Uncomment
                RepositoryItemAYTMemoExEdit.RapidSpell.ContextMenuStripEnabled = False

            End If
        End Sub

        Public Shared Sub Register()
            EditorRegistrationInfo.Default.Editors.Add(New EditorClassInfo(EditorName, GetType(AYTMemoExEdit), _
                GetType(RepositoryItemAYTMemoExEdit), _
                GetType(DevExpress.XtraEditors.ViewInfo.TextEditViewInfo), _
                New DevExpress.XtraEditors.Drawing.MemoEditPainter, True))
        End Sub
    End Class
#End Region

#Region "AYTTextEdit"
    ''' <summary>
    ''' Summary description for AYTTextEdit.
    ''' </summary>
    Public Class AYTTextEdit
        Inherits TextEdit

        Private tb As AYTTextBoxMaskBox

        Private connector As Keyoti.RapidSpell.ThirdParty.DevExpress6.TextBoxConnector


        'thesaurus
        Private thesaurus1 As Keyoti.Thesaurus.Windows.Thesaurus
        Friend WithEvents thesContextMenu As ContextMenu

        Private Sub thesContextMenu_Popup(ByVal sender As Object, ByVal e As System.EventArgs) Handles thesContextMenu.Popup
            thesContextMenu.MenuItems.Clear()

            'see if any spelling suggestions
            Dim spellingSuggestions As MenuItem() = RepositoryItemAYTTextEdit.RapidSpell.GetSuggestions()
            If Not (spellingSuggestions Is Nothing) Then
                thesContextMenu.MenuItems.AddRange(spellingSuggestions)
                thesContextMenu.MenuItems.Add("-")
            End If

            'add synonymns (thesaurus submenu), if not in header/footer
            Dim synonymsMenuItem As New MenuItem("Synonyms")
            thesContextMenu.MenuItems.Add(synonymsMenuItem)
            Dim thSuggestions As MenuItem() = Me.thesaurus1.GetSuggestionMenuItems()
            Dim noSuggestionsMenuItem As New MenuItem("(No suggestions)")

            noSuggestionsMenuItem.Enabled = False
            synonymsMenuItem.MenuItems.Clear()
            If Not (thSuggestions Is Nothing) Then
                synonymsMenuItem.MenuItems.AddRange(thSuggestions)
            Else
                synonymsMenuItem.MenuItems.Add(noSuggestionsMenuItem)
            End If


        End Sub

        Shared Sub New()
            RepositoryItemAYTTextEdit.Register()
            RepositoryItemAYTTextEdit.InitRapidSpellAsYouType()
        End Sub

        Public Overrides ReadOnly Property EditorTypeName() As String
            Get
                Return RepositoryItemAYTTextEdit.EditorName
            End Get
        End Property

        Public Shadows ReadOnly Property Properties() As RepositoryItemAYTTextEdit
            Get
                Return CType(MyBase.Properties, RepositoryItemAYTTextEdit)
            End Get
        End Property

        Public ReadOnly Property AsYouTypeTextBox() As Keyoti.RapidSpell.IAYTTextBox
            Get
                Return connector
            End Get
        End Property

        Protected Overrides Function CreateMaskBoxInstance() As TextBoxMaskBox
            Dim rsayt As Keyoti.RapidSpell.RapidSpellAsYouType
            rsayt = RepositoryItemAYTTextEdit.RapidSpell
            connector = New Keyoti.RapidSpell.ThirdParty.DevExpress6.TextBoxConnector

            tb = New AYTTextBoxMaskBox(Me, connector)
            connector.WrappedTextBox = tb
            rsayt.RapidSpellChecker.ShareDictionary = True

            'thesaurus - this must be called before rapidSpellAsYouType1.TextComponent is set
            thesaurus1 = New Keyoti.Thesaurus.Windows.Thesaurus
            thesaurus1.TextBoxBase = tb
            rsayt.ShowSuggestionsContextMenu = False
            thesContextMenu = New ContextMenu
            tb.ContextMenu = thesContextMenu
            '----------------------------------------------------------------------------------


            rsayt.TextComponent = connector
            connector.UnderlineYOffset = GlueVars.UnderlineYOffset


            Return tb
        End Function
    End Class


#End Region

#Region "AYTMemoEdit"

    Public Class AYTMemoEdit
        Inherits DevExpress.XtraEditors.MemoEdit
        Implements Keyoti.RapidSpell.ISpellCheckableTextComponent



        Private rapidSpellAsYouType1 As Keyoti.RapidSpell.RapidSpellAsYouType

        'thesaurus
        Private thesaurus1 As Keyoti.Thesaurus.Windows.Thesaurus
        Friend WithEvents thesContextMenu As ContextMenu

        Private Sub thesContextMenu_Popup(ByVal sender As Object, ByVal e As System.EventArgs) Handles thesContextMenu.Popup
            thesContextMenu.MenuItems.Clear()

            'see if any spelling suggestions
            Dim spellingSuggestions As MenuItem() = Me.rapidSpellAsYouType1.GetSuggestions()
            If Not (spellingSuggestions Is Nothing) Then
                thesContextMenu.MenuItems.AddRange(spellingSuggestions)
                thesContextMenu.MenuItems.Add("-")
            End If

            'add synonymns (thesaurus submenu), if not in header/footer
            Dim synonymsMenuItem As New MenuItem("Synonyms")
            thesContextMenu.MenuItems.Add(synonymsMenuItem)
            Dim thSuggestions As MenuItem() = Me.thesaurus1.GetSuggestionMenuItems()
            Dim noSuggestionsMenuItem As New MenuItem("(No suggestions)")

            noSuggestionsMenuItem.Enabled = False
            synonymsMenuItem.MenuItems.Clear()
            If Not (thSuggestions Is Nothing) Then
                synonymsMenuItem.MenuItems.AddRange(thSuggestions)
            Else
                synonymsMenuItem.MenuItems.Add(noSuggestionsMenuItem)
            End If


        End Sub



        Protected Overrides Function CreateMaskBoxInstance() As DevExpress.XtraEditors.TextBoxMaskBox
            rapidSpellAsYouType1 = New Keyoti.RapidSpell.RapidSpellAsYouType
            Dim connector As Keyoti.RapidSpell.ThirdParty.DevExpress6.TextBoxConnector = New Keyoti.RapidSpell.ThirdParty.DevExpress6.TextBoxConnector
            Dim tb As AYTTextBoxMaskBox = New AYTTextBoxMaskBox(Me, connector)
            Dim parentf As Form = Me.FindForm()
            If Not parentf Is Nothing Then
                AddHandler parentf.Load, New EventHandler(AddressOf OnLoad)
            End If
            connector.WrappedTextBox = tb
            'VS2005 Uncomment
            rapidSpellAsYouType1.ContextMenuStripEnabled = False
            rapidSpellAsYouType1.RapidSpellChecker.ShareDictionary = True

            'thesaurus - this must be called before rapidSpellAsYouType1.TextComponent is set
            thesaurus1 = New Keyoti.Thesaurus.Windows.Thesaurus
            thesaurus1.TextBoxBase = tb
            rapidSpellAsYouType1.ShowSuggestionsContextMenu = False
            thesContextMenu = New ContextMenu
            tb.ContextMenu = thesContextMenu
            '----------------------------------------------------------------------------------


            rapidSpellAsYouType1.TextComponent = connector
            Return tb
        End Function

        Public Sub OnLoad(ByVal s As Object, ByVal e As EventArgs)
            rapidSpellAsYouType1.ForceCheckAll()
        End Sub

#Region "ISpellCheckableTextComponent implementation"
        Protected Overrides Sub OnEnter(ByVal e As EventArgs)
            RaiseEvent GotFocus1(Me, e)
        End Sub


        Public Event GotFocus1(ByVal sender As Object, ByVal e As System.EventArgs) Implements ISpellCheckableTextComponent.GotFocus

        Public Property HideSelection() As Boolean Implements ISpellCheckableTextComponent.HideSelection
            Get
                Return Properties.HideSelection
            End Get
            Set(ByVal Value As Boolean)
                Properties.HideSelection = Value
            End Set
        End Property

        Public Sub ScrollToCaret1() Implements ISpellCheckableTextComponent.ScrollToCaret
            ScrollToCaret()
        End Sub

        Public Property SelectedText1() As String Implements ISpellCheckableTextComponent.SelectedText
            Get
                Return SelectedText
            End Get
            Set(ByVal Value As String)
                SelectedText = Value
            End Set
        End Property

        Public Property SelectionLength1() As Integer Implements ISpellCheckableTextComponent.SelectionLength
            Get
                Return SelectionLength
            End Get
            Set(ByVal Value As Integer)
                SelectionLength = Value
            End Set
        End Property

        Public Property SelectionStart1() As Integer Implements ISpellCheckableTextComponent.SelectionStart
            Get
                Return SelectionStart
            End Get
            Set(ByVal Value As Integer)
                SelectionStart = Value
            End Set
        End Property

        Public Property Text1() As String Implements ISpellCheckableTextComponent.Text
            Get
                Return Text
            End Get
            Set(ByVal Value As String)
                Text = Value
            End Set
        End Property
#End Region
    End Class
#End Region

#Region "Support - AYTTextBoxMaskBox"

    Public Class AYTTextBoxMaskBox
        Inherits BaseTextBoxMaskBox


        Private box As Keyoti.RapidSpell.IAYTTextBox

        '''<summary>Creates a new TextBox with "as-you-type" facility.</summary>
        Public Sub New(ByVal ownerEdit As DevExpress.XtraEditors.TextEdit, ByVal box As Keyoti.RapidSpell.IAYTTextBox)
            MyBase.New(ownerEdit)
            Me.box = box

        End Sub

        Public Overrides Property ContextMenu() As ContextMenu
            Get
                Return MyBase.ContextMenu
            End Get
            Set(ByVal Value As ContextMenu)
                If (MyBase.ContextMenu Is Nothing) Then
                    MyBase.ContextMenu = Value
                End If
            End Set
        End Property

        '''<summary>Handles WndProc events and dispatches new events.</summary>
        Protected Overrides Sub WndProc(ByRef m As Message)
            If CType(Me.box, Keyoti.RapidSpell.ThirdParty.DevExpress6.IThirdPartyTextBoxConnector).WndProc(m) Then
                MyBase.WndProc(m)
            End If
        End Sub


    End Class
#End Region

#Region "AYTMemoExEdit"
    Public Class AYTMemoExEdit
        Inherits DevExpress.XtraEditors.MemoExEdit

        Protected Overrides Function CreatePopupForm() As DevExpress.XtraEditors.Popup.PopupBaseForm
            Return New AYTMemoExPopupForm(Me)
        End Function
    End Class

    Public Class AYTMemoExPopupForm
        Inherits DevExpress.XtraEditors.Popup.MemoExPopupForm

        Private aytmemo As AYTMemoEdit

        Public Sub New(ByVal ownerEdit As DevExpress.XtraEditors.MemoExEdit)
            MyBase.New(ownerEdit)
            aytmemo.ContextMenu = New ContextMenu
            If (Me.OwnerEdit.LookAndFeel.ActiveStyle <> DevExpress.LookAndFeel.ActiveLookAndFeelStyle.Skin) Then
                Me.aytmemo.Properties.BorderStyle = DevExpress.XtraEditors.Controls.BorderStyles.Simple
            End If
            Me.aytmemo.Properties.Appearance.Assign(ownerEdit.Properties.AppearanceDropDown)
            Me.aytmemo.Visible = False
            AddHandler aytmemo.Modified, AddressOf Me.OnMemo_Modified
            MyBase.Controls.Add(Me.aytmemo)
            Me.UpdateMemo()
        End Sub

        Protected Overrides ReadOnly Property Memo() As DevExpress.XtraEditors.MemoEdit
            Get
                If Me.aytmemo Is Nothing Then
                    Me.aytmemo = New AYTMemoEdit
                End If
                Return Me.aytmemo
            End Get
        End Property
    End Class
#End Region

#Region "Inherited member interface implementation"
    Public Class BaseTextBoxMaskBox
        Inherits DevExpress.XtraEditors.TextBoxMaskBox
        Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox


        Public Sub New(ByVal ownerEdit As DevExpress.XtraEditors.TextEdit)
            MyBase.New(ownerEdit)

        End Sub



        Public Sub AppendText1(ByVal text As String) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.AppendText
            MyBase.AppendText(text)
        End Sub

        Public Overloads Function BeginInvoke1(ByVal d As System.Delegate) As System.IAsyncResult Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.BeginInvoke
            MyBase.BeginInvoke(d)
        End Function

        Public Overloads Function BeginInvoke2(ByVal d As System.Delegate, ByVal parameters() As Object) As System.IAsyncResult Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.BeginInvoke
            MyBase.BeginInvoke(d, parameters)
        End Function

        Public Sub CallWndProc(ByRef m As System.Windows.Forms.Message) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.CallWndProc
            MyBase.WndProc(m)
        End Sub

        Public Sub Clear1() Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Clear
            MyBase.Clear()
        End Sub

        Public Sub ClearUndo1() Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.ClearUndo
            MyBase.ClearUndo()
        End Sub

        Public Property ClientSize1() As System.Drawing.Size Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.ClientSize
            Get
                Return MyBase.ClientSize
            End Get
            Set(ByVal Value As System.Drawing.Size)
                MyBase.ClientSize = Value

            End Set
        End Property

        Public Property ContextMenu1() As System.Windows.Forms.ContextMenu Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.ContextMenu
            Get
                Return ContextMenu
            End Get
            Set(ByVal Value As System.Windows.Forms.ContextMenu)
                ContextMenu = Value

            End Set
        End Property


        Public Property ContextMenuStrip1() As System.Windows.Forms.ContextMenuStrip Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.ContextMenuStrip
            Get
                Return ContextMenuStrip
            End Get
            Set(ByVal Value As System.Windows.Forms.ContextMenuStrip)
                ContextMenuStrip = Value

            End Set
        End Property

        Public Sub Copy1() Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Copy
            Copy()
        End Sub

        Public Sub Cut1() Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Cut
            Cut()
        End Sub

        Public Event Disposed1(ByVal sender As Object, ByVal e As System.EventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Disposed

        Public Property EditText1() As String Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.EditText
            Get
                Return EditText
            End Get
            Set(ByVal Value As String)
                EditText = Value

            End Set
        End Property

        Public Event Enter1(ByVal sender As Object, ByVal e As System.EventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Enter

        Public Property Font1() As System.Drawing.Font Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Font
            Get
                Return Font
            End Get
            Set(ByVal Value As System.Drawing.Font)
                Font = Value
            End Set
        End Property

        Public Event FontChanged1(ByVal sender As Object, ByVal e As System.EventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.FontChanged

        Public ReadOnly Property Handle1() As System.IntPtr Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Handle
            Get
                Return Handle
            End Get
        End Property

        Public Property Height1() As Integer Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Height
            Get
                Return Height
            End Get
            Set(ByVal Value As Integer)
                Height = Value
            End Set
        End Property

        Public ReadOnly Property IsDisposed1() As Boolean Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.IsDisposed
            Get
                Return IsDisposed
            End Get
        End Property

        Public ReadOnly Property IsHandleCreated1() As Boolean Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.IsHandleCreated
            Get
                Return IsHandleCreated
            End Get
        End Property

        Public Event KeyDown1(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyEventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.KeyDown

        Public Event KeyUp1(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyEventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.KeyUp

        Public Event Leave1(ByVal sender As Object, ByVal e As System.EventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Leave

        Public Property MaskBoxSelectedText1() As String Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.MaskBoxSelectedText
            Get
                Return MaskBoxSelectedText
            End Get
            Set(ByVal Value As String)
                MaskBoxSelectedText = Value

            End Set
        End Property

        Public Property MaskBoxSelectionLength1() As Integer Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.MaskBoxSelectionLength
            Get
                Return MaskBoxSelectionLength
            End Get
            Set(ByVal Value As Integer)
                MaskBoxSelectionLength = Value
            End Set
        End Property

        Public Property MaskBoxSelectionStart1() As Integer Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.MaskBoxSelectionStart
            Get
                Return MaskBoxSelectionStart
            End Get
            Set(ByVal Value As Integer)
                MaskBoxSelectionStart = Value
            End Set
        End Property

        Public ReadOnly Property MaskBoxText1() As String Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.MaskBoxText
            Get
                Return MaskBoxText
            End Get
        End Property

        Public Event MouseDown1(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.MouseDown

        Public Event MouseUp1(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.MouseUp

        Public Event MouseWheel1(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.MouseWheel

        Public Sub Paste1() Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Paste
            Paste()
        End Sub

        Public Sub Refresh1() Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Refresh
            Refresh()
        End Sub

        Public Event Resize1(ByVal sender As Object, ByVal e As System.EventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Resize

        Public Sub SelectAll1() Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.SelectAll
            MaskBoxSelectAll()
        End Sub

        Public Property SelectedText1() As String Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.SelectedText
            Get
                Return MaskBoxSelectedText
            End Get
            Set(ByVal Value As String)
                MaskBoxSelectedText = Value
            End Set
        End Property

        Public Property SelectionLength1() As Integer Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.SelectionLength
            Get
                Return MaskBoxSelectionLength

            End Get
            Set(ByVal Value As Integer)
                MaskBoxSelectionLength = Value
            End Set
        End Property

        Public Property SelectionStart1() As Integer Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.SelectionStart
            Get
                Return MaskBoxSelectionStart

            End Get
            Set(ByVal Value As Integer)
                MaskBoxSelectionStart = Value
            End Set
        End Property

        Public Sub SuspendLayout1() Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.SuspendLayout
            SuspendLayout()

        End Sub

        Public Property Text1() As String Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Text
            Get
                Return EditText

            End Get
            Set(ByVal Value As String)
                EditText = Value
            End Set
        End Property

        Public Event TextChanged1(ByVal sender As Object, ByVal e As System.EventArgs) Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.TextChanged

        Public ReadOnly Property TextLength1() As Integer Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.TextLength
            Get
                Return TextLength
            End Get
        End Property

        Public Sub Undo1() Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Undo
            MaskBoxUndo()
        End Sub

        Public Property Width1() As Integer Implements Keyoti.RapidSpell.ThirdParty.DevExpress6.ITextBoxMaskBox.Width
            Get
                Return Width
            End Get
            Set(ByVal Value As Integer)
                Width = Value
            End Set
        End Property

        Private Sub BaseTextBoxMaskBox_Enter(ByVal sender As Object, ByVal e As System.EventArgs) Handles MyBase.Enter
            RaiseEvent Enter1(sender, e)
        End Sub

        Private Sub BaseTextBoxMaskBox_Disposed(ByVal sender As Object, ByVal e As System.EventArgs) Handles MyBase.Disposed
            RaiseEvent Disposed1(sender, e)
        End Sub


        Private Sub BaseTextBoxMaskBox_FontChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles MyBase.FontChanged
            RaiseEvent FontChanged1(sender, e)
        End Sub


        Private Sub BaseTextBoxMaskBox_KeyDown(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyEventArgs) Handles MyBase.KeyDown
            RaiseEvent KeyDown1(sender, e)
        End Sub

        Private Sub BaseTextBoxMaskBox_KeyUp(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyEventArgs) Handles MyBase.KeyUp
            RaiseEvent KeyUp1(sender, e)
        End Sub


        Private Sub BaseTextBoxMaskBox_Leave(ByVal sender As Object, ByVal e As System.EventArgs) Handles MyBase.Leave
            RaiseEvent Leave1(sender, e)
        End Sub


        Private Sub BaseTextBoxMaskBox_MouseDown(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles MyBase.MouseDown
            RaiseEvent MouseDown1(sender, e)
        End Sub


        Private Sub BaseTextBoxMaskBox_MouseUp(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles MyBase.MouseUp
            RaiseEvent MouseUp1(sender, e)
        End Sub


        Private Sub BaseTextBoxMaskBox_MouseWheel(ByVal sender As Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles MyBase.MouseWheel
            RaiseEvent MouseWheel1(sender, e)
        End Sub

        Private Sub BaseTextBoxMaskBox_Resize(ByVal sender As Object, ByVal e As System.EventArgs) Handles MyBase.Resize
            RaiseEvent Resize1(sender, e)
        End Sub


        Private Sub BaseTextBoxMaskBox_TextChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles MyBase.TextChanged
            RaiseEvent TextChanged1(sender, e)
        End Sub

    End Class
#End Region

End Namespace